@@ -6,16 +6,16 @@ function(x, ...)
     #if(!is.null(x$messages)){ message(x$messages) }
     
     ##header:
-    cat("\\n")
-    cat("Date:", x$date, "\\n")
-    cat("Dependent var.:", x$aux$y.name, "\\n")
-    cat("Method: Ordinary Least Squares (OLS)\\n")
+    cat("\n")
+    cat("Date:", x$date, "\n")
+    cat("Dependent var.:", x$aux$y.name, "\n")
+    cat("Method: Ordinary Least Squares (OLS)\n")
     cat("Variance-Covariance:", switch(x$aux$vcov.type,
                                        ordinary = "Ordinary", white = "White (1980)",
-                                       "newey-west" = "Newey and West (1987)"), "\\n")
+                                       "newey-west" = "Newey and West (1987)"), "\n")
     
     ##header - sample info:
-    cat("No. of observations (mean eq.):", x$aux$y.n, "\\n")
+    cat("No. of observations (mean eq.):", x$aux$y.n, "\n")
     tmp <- zoo(x$aux$y, order.by=x$aux$y.index)
     
     indexTrimmed <- index(na.trim(tmp))
@@ -33,54 +33,54 @@ function(x, ...)
       startAsChar <- as.character(indexTrimmed[1])
       endAsChar <- as.character(indexTrimmed[length(indexTrimmed)])
     }
-    cat("Sample:", startAsChar, "to", endAsChar, "\\n")
+    cat("Sample:", startAsChar, "to", endAsChar, "\n")
     
     ####### START the part commented out 17 July 2019 by G-man:  
     #
     #  ##gum:
     #  if(specType=="mean"){
-    #    cat("\\n")
-    #    cat("GUM mean equation:\\n")
-    #    cat("\\n")
+    #    cat("\n")
+    #    cat("GUM mean equation:\n")
+    #    cat("\n")
     #    printCoefmat(x$gum.mean, dig.tst=0, tst.ind=c(1,2),
     #                 signif.stars=FALSE, P.values=FALSE, has.Pvalue=FALSE)
     #  }
     #  if(!is.null(x$gum.variance)){
-    #    cat("\\n")
-    #    cat("GUM log-variance equation:\\n")
-    #    cat("\\n")
+    #    cat("\n")
+    #    cat("GUM log-variance equation:\n")
+    #    cat("\n")
     #    printCoefmat(x$gum.variance, signif.stars=FALSE)
     #  }
-    #  cat("\\n")
-    #  cat("Diagnostics and fit:\\n")
-    #  cat("\\n")
+    #  cat("\n")
+    #  cat("Diagnostics and fit:\n")
+    #  cat("\n")
     #  printCoefmat(x$gum.diagnostics, dig.tst=0, tst.ind=2,
     #               signif.stars=FALSE, P.values=FALSE, has.Pvalue=FALSE)
     #  
     #
     #  ##paths:
-    #  cat("\\n")
-    #  cat("Paths searched: \\n")
-    #  cat("\\n")
+    #  cat("\n")
+    #  cat("Paths searched: \n")
+    #  cat("\n")
     #  if(is.null(x$paths)){
     #    print(NULL)
     #  }else{
     #    for(i in 1:length(x$paths)){
-    #      cat("path",i,":",x$paths[[i]],"\\n")
+    #      cat("path",i,":",x$paths[[i]],"\n")
     #    }
     #  } #end if(is.null(x$paths))
     #  
     #  ##terminal models and results:
     #  if(!is.null(x$terminals)){
-    #    cat("\\n")
-    #    cat("Terminal models: \\n")
-    #    cat("\\n")
+    #    cat("\n")
+    #    cat("Terminal models: \n")
+    #    cat("\n")
     #    for(i in 1:length(x$terminals)){
-    #      cat("spec",i,":",x$terminals[[i]],"\\n")
+    #      cat("spec",i,":",x$terminals[[i]],"\n")
     #    }
     #  }
     #  if(!is.null(x$terminals.results)){
-    #    cat("\\n")
+    #    cat("\n")
     #    printCoefmat(x$terminals.results, dig.tst=0, tst.ind=c(3,4),
     #                 signif.stars=FALSE)
     #  }
@@ -89,9 +89,9 @@ function(x, ...)
     
     ##specific model:
     if(!is.null(x$specific.spec)){
-      cat("\\n")
-      cat("SPECIFIC mean equation:\\n")
-      cat("\\n")
+      cat("\n")
+      cat("SPECIFIC mean equation:\n")
+      cat("\n")
       if(!is.null(x$mean.results)){
         print(x$mean.results)
         #OLD: DOES NOT WORK IN A PREDICTABLE WAY!
@@ -99,11 +99,11 @@ function(x, ...)
         #        P.values=FALSE, has.Pvalues=FALSE)
       }
       if(x$specific.spec[1]==0){
-        cat("empty\\n")
+        cat("empty\n")
       }
       ##in the future: use estimate.specific=FALSE more directly?
       if(x$specific.spec[1]!=0 && is.null(x$mean.results)){
-        cat("Not estimated\\n")
+        cat("Not estimated\n")
       }
     }
     
@@ -120,9 +120,9 @@ function(x, ...)
       mGOF[3,1] <- as.numeric(logLik.isat(x)) #OLD: x$logl
       #mGOF[4,1] <- outliertest(x)$#x$logl #OLD: as.numeric(logLik.arx(x))
       
-      cat("\\n")
-      cat("Diagnostics and fit:\\n")
-      cat("\\n")
+      cat("\n")
+      cat("Diagnostics and fit:\n")
+      cat("\n")
       printCoefmat(x$diagnostics, dig.tst=0, tst.ind=2,
                    signif.stars=FALSE)
       if(!is.null(x$call$iis)){
@@ -134,9 +134,9 @@ function(x, ...)
         rownames(mOutl) <- c("Jiao-Pretis Prop.", "Jiao-Pretis Count")
         mOutl[1,] <- c(outltest$prop$statistic, outltest$prop$p.value)
         mOutl[2,] <- c(outltest$count$statistic, outltest$count$p.value)
-        cat("\\n")
+        cat("\n")
         printCoefmat(mOutl, digits=6, signif.stars = FALSE) 
-        #cat("\\n")
+        #cat("\n")
         }
       }
       printCoefmat(mGOF, digits=6, signif.stars=FALSE)
