@@ -1,7 +1,7 @@
 sigma.arx <-
 function(object, ...)
 {
-  residsTrimmed <- na.trim(object$resids)
+  residsTrimmed <- na.trim(object$residuals)
   RSS <- sum(residsTrimmed^2)
   nobs <- length(residsTrimmed)
   DFs <- length(coef.arx(object, spec="mean"))
